@@ -46,7 +46,7 @@ struct XpadPadGroup
 struct XpadPadGroupClass
 {
 	GObjectClass parent_class;
-	
+
 	void (* pad_added)      (XpadPadGroup *group, GtkWidget *pad);
 };
 
@@ -54,17 +54,18 @@ GType    xpad_pad_group_get_type (void);
 
 XpadPadGroup *xpad_pad_group_new      (void);
 
-void     xpad_pad_group_add      (XpadPadGroup *group, GtkWidget *pad);
-void     xpad_pad_group_remove   (XpadPadGroup *group, GtkWidget *pad);
+void     xpad_pad_group_add                          (XpadPadGroup *group, GtkWidget *pad);
+void     xpad_pad_group_remove                       (XpadPadGroup *group, GtkWidget *pad);
 
-void     xpad_pad_group_close_all        (XpadPadGroup *group);
-void     xpad_pad_group_show_all         (XpadPadGroup *group);
-void     xpad_pad_group_toggle_hide      (XpadPadGroup *group);
-GSList * xpad_pad_group_get_pads         (XpadPadGroup *group);
-guint    xpad_pad_group_num_pads         (XpadPadGroup *group);
-guint    xpad_pad_group_num_visible_pads (XpadPadGroup *group);
-void     xpad_pad_group_destroy_pads     (XpadPadGroup *group);
-void     xpad_pad_group_update_sticky    (XpadPadGroup *group, gboolean is_sticky);
+void     xpad_pad_group_close_all                    (XpadPadGroup *group);
+void     xpad_pad_group_show_all                     (XpadPadGroup *group);
+void     xpad_pad_group_toggle_hide                  (XpadPadGroup *group);
+GSList*  xpad_pad_group_get_pads                     (XpadPadGroup *group);
+GSList*  xpad_pad_group_get_pads_sorted_by_title     (XpadPadGroup *group);
+guint    xpad_pad_group_num_visible_pads             (XpadPadGroup *group);
+void     xpad_pad_group_destroy_pads                 (XpadPadGroup *group);
+void     xpad_pad_group_update_sticky                (XpadPadGroup *group, gboolean is_sticky);
+gboolean xpad_pad_group_has_pads                     (XpadPadGroup *group);
 
 G_END_DECLS
 
