@@ -1,6 +1,7 @@
 /*
 
 Copyright (c) 2001-2007 Michael Terry
+Copyright (c) 2013-2014 Arthur Borsboom
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,7 +22,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __XPAD_SESSION_MANAGER_H__
 #define __XPAD_SESSION_MANAGER_H__
 
-#include <gtk/gtk.h>
+#include <glib.h>
+
+G_BEGIN_DECLS
 
 gboolean xpad_session_manager_start_interact (gboolean error);
 void     xpad_session_manager_stop_interact (gboolean stop_shutdown);
@@ -29,4 +32,6 @@ void     xpad_session_manager_init (void);
 void     xpad_session_manager_shutdown (void);
 void     xpad_session_manager_set_id (const gchar *id);
 
+G_END_DECLS
+
 #endif /* __XPAD_SESSION_MANAGER_H__ */
