@@ -29,7 +29,7 @@ G_BEGIN_DECLS
 
 void xpad_tray_init (XpadSettings *settings);
 void xpad_tray_dispose (XpadSettings *settings);
-gboolean xpad_tray_is_open ();
+gboolean xpad_tray_has_indicator ();
 
 G_END_DECLS
 
